searchData={"items":[{"type":"module","title":"PyroComponents.Ecto.ZonedDateTime","doc":"Wraps a datetime in a map with a timezone to edit/display datetimes in a given timezone in input components.","ref":"PyroComponents.Ecto.ZonedDateTime.html"},{"type":"module","title":"PyroComponents","doc":"`Pyro` is a component library for `Phoenix`.\n\nTo learn more, check out the [About](about.html) page.\n\nTo install, follow the [Get Started](get-started.html) guide.\n\n The easiest way to use PyroComponents is to import them into `my_app_web.ex` helpers to make the available in all views and components:\n\n ```elixir\n defp html_helpers do\n   quote do\n     # Import all PyroComponents\n     use PyroComponents\n     # ...\n ```\n\nComprehensive installation instructions can be found in [Get Started](get-started.md).\n\nPyro provides components that support deep customization through `Pyro.Overrides`, and also tooling to create your own via `Pyro.Component`.\n\n> ##","ref":"PyroComponents.html"},{"type":"module","title":"Note: {: .warning} - PyroComponents","doc":">\n> Pyro's component names conflict with the generated `CoreComponents`. You will need to remove `import MyAppWeb.CoreComponents`.","ref":"PyroComponents.html#module-note-warning"},{"type":"module","title":"PyroComponents.Overrides.BEM","doc":"This overrides file adds [BEM](https://getbem.com/) classes to all Pyro components. It does not define any style.\n\nThis is great if you want to fully customize your own styles; all you have to do is define the classes in your CSS file.","ref":"PyroComponents.Overrides.BEM.html"},{"type":"module","title":"Configuration - PyroComponents.Overrides.BEM","doc":"As with any Pyro overrides, you need to include the override file in your `config.exs` file:\n\n```elixir\nconfig :pyro, :overrides, [PyroComponents.Overrides.BEM]\n```\n\nThen, just implement the component classes listed in [Overrides](#module-overrides) in your CSS file.\n\nIn addition to the component classes, Pyro also expects the following utility classes to be implemented:\n\n```css\n.hidden {\n  display: none;\n}\n```\n\nYou can override specific settings by merging in your own overrides file, as described [here](`Pyro.Overrides`). Additionally, the BEM overrides file supports a few application config options:\n\n```elixir\n# Prefix applied to all BEM classes, useful for namespacing Pyro's components in a brownfield project.\n# Defaults to `\"\"`\nconfig :pyro_components, :bem_prefix, \"pyro-\"\n\n# Specify color variants. Defaults to all Tailwind colors families.\nconfig :pyro_components, :bem_color_variants, [\"red\", \"green\", \"brand\"]\n\n# Specify flash variants. Defaults to `~w[info error warning success]`\nconfig :pyro_components, :bem_flash_variants, [\"danger\", \"warning\"]\n\n# Specify size variants. Defaults to `~w[xs sm base lg xl]`\nconfig :pyro_components, :bem_size_variants, [\"normal\", \"huge\"]\n\n# Specify button variants. Defaults to `~w[solid outline]`\nconfig :pyro_components, :bem_button_variants, [\"normal\", \"ghost\"]\n```","ref":"PyroComponents.Overrides.BEM.html#module-configuration"},{"type":"module","title":"Using with Tailwind - PyroComponents.Overrides.BEM","doc":"The class names are built dynamically, so if you want to use Tailwind, you will need to implement your styles *without* the layer directive to ensure they are always included, and you will need to ensure you put them before the utilities import for correct precedence:\n\n```css\n@tailwind base;\n@tailwind components;\n\n/* This will always be included in your compiled CSS */\n.button {\n  /* ... */\n}\n\n@tailwind utilities;\n```\n\nAlso, be sure to remove any Pyro-related files from your `content` list in `tailwind.config.js`, otherwise you will be including unused classes from other override skins.\n\n- Captured functions with arity 1 and the arg named `passed_assigns` are passed component assigns at runtime, allowing complex conditional logic\n- [`assign_overridables/1`](`Pyro.Component.assign_overridables/1`) preserves the definition order of attrs and assigns them in that order, preserving dependency chains\n- Attrs with type `:css_classes` utilize the configured CSS merge utility","ref":"PyroComponents.Overrides.BEM.html#module-using-with-tailwind"},{"type":"module","title":"Overrides - PyroComponents.Overrides.BEM","doc":"- `Elixir.PyroComponents.Components.Autocomplete.render/1`\n  - `:listbox_class` `\"pyro_autocomplete__listbox\"`\n  - `:option_value_key` `:id`\n  - `:throttle_time` `212`\n  - `:listbox_option_class` `\"pyro_autocomplete__listbox_option\"`\n  - `:description_class` `\"pyro_input__description\"`\n  - `:prompt` `\"Search options\"`\n  - `:class` `\"pyro_autocomplete\"`\n  - `:option_label_key` `:label`\n  - `:input_class` `PyroComponents.Overrides.BEM.input_class/1`\n\n- `Elixir.PyroComponents.Components.Core.a/1`\n  - `:replace` `false`\n  - `:class` `\"pyro_a\"`\n\n- `Elixir.PyroComponents.Components.Core.button/1`\n  - `:class` `PyroComponents.Overrides.BEM.button_class/1`\n  - `:ping_class` `\"pyro_button__ping\"`\n  - `:icon_class` `\"pyro_button__icon\"`\n  - `:color` `\"slate\"`\n  - `:variant` `\"solid\"`\n  - `:size` `\"base\"`\n  - `:ping_animation_class` `\"pyro_button__ping_animation\"`\n  - `:colors` `[\"slate\", \"gray\", \"zinc\", \"neutral\", \"stone\", \"red\", \"orange\", \"amber\", \"yellow\", \"lime\", \"green\", \"emerald\", \"teal\", \"cyan\", \"sky\", \"blue\", \"indigo\", \"violet\", \"purple\", \"fuchsia\", \"pink\", \"rose\"]`\n  - `:variants` `[\"solid\", \"outline\"]`\n  - `:sizes` `[\"xs\", \"sm\", \"base\", \"lg\", \"xl\"]`\n\n- `Elixir.PyroComponents.Components.Core.code/1`\n  - `:copy_class` `\"pyro_code__copy\"`\n  - `:copy_label` `\"Copy\"`\n  - `:class` `\"pyro_code makeup\"`\n  - `:copy` `true`\n\n- `Elixir.PyroComponents.Components.Core.color_scheme_switcher/1`\n  - `:label_system` `\"System\"`\n  - `:label_dark` `\"Dark\"`\n  - `:icon_system` `\"hero-computer-desktop-mini\"`\n  - `:class` `\"pyro_color_scheme_switcher\"`\n  - `:icon_dark` `\"hero-moon-solid\"`\n  - `:label_light` `\"Light\"`\n  - `:scheme` `PyroComponents.Overrides.BEM.color_scheme_switcher_scheme/1`\n  - `:icon_light` `\"hero-sun-solid\"`\n\n- `Elixir.PyroComponents.Components.Core.copy_to_clipboard/1`\n  - `:color` `\"slate\"`\n  - `:class` `PyroComponents.Overrides.BEM.button_class/1`\n  - `:ttl` `3000`\n  - `:sizes` `[\"xs\", \"sm\", \"base\", \"lg\", \"xl\"]`\n  - `:variants` `[\"solid\", \"outline\"]`\n  - `:icon_class` `\"pyro_button__icon\"`\n  - `:variant` `\"solid\"`\n  - `:size` `\"base\"`\n  - `:colors` `[\"slate\", \"gray\", \"zinc\", \"neutral\", \"stone\", \"red\", \"orange\", \"amber\", \"yellow\", \"lime\", \"green\", \"emerald\", \"teal\", \"cyan\", \"sky\", \"blue\", \"indigo\", \"violet\", \"purple\", \"fuchsia\", \"pink\", \"rose\"]`\n  - `:message` `\"Copied! 📋\"`\n\n- `Elixir.PyroComponents.Components.Core.error/1`\n  - `:icon_name` `\"hero-exclamation-circle-mini\"`\n  - `:icon_class` `\"pyro_error__icon\"`\n  - `:class` `\"pyro_error\"`\n\n- `Elixir.PyroComponents.Components.Core.flash/1`\n  - `:close_button_class` `\"pyro_flash__close_button\"`\n  - `:close_icon_class` `\"pyro_flash__close_icon\"`\n  - `:ttl` `10000`\n  - `:hide_js` `PyroComponents.Overrides.BEM.flash_hide_js/2`\n  - `:class` `\"pyro_flash\"`\n  - `:close` `true`\n  - `:close_icon_name` `\"hero-x-mark-mini\"`\n  - `:message_class` `\"pyro_flash__message\"`\n  - `:title` `PyroComponents.Overrides.BEM.flash_title/1`\n  - `:kinds` `[\"info\", \"error\", \"warning\", \"success\"]`\n  - `:autoshow` `true`\n  - `:control_class` `\"pyro_flash__control\"`\n  - `:icon_name` `PyroComponents.Overrides.BEM.flash_icon_name/1`\n  - `:kind` `\"info\"`\n  - `:show_js` `PyroComponents.Overrides.BEM.flash_show_js/2`\n  - `:progress_class` `\"pyro_flash__progress\"`\n  - `:title_class` `\"pyro_flash__title\"`\n  - `:title__icon_class` `\"pyro_flash__title_icon\"`\n\n- `Elixir.PyroComponents.Components.Core.flash_group/1`\n  - `:class` `\"pyro_flash_group\"`\n  - `:include_kinds` `[\"info\", \"error\", \"warning\", \"success\"]`\n\n- `Elixir.PyroComponents.Components.Core.header/1`\n  - `:actions_class` `\"pyro_header__actions\"`\n  - `:title_class` `\"pyro_header__title\"`\n  - `:class` `\"pyro_header\"`\n  - `:subtitle_class` `\"pyro_header__subtitle\"`\n\n- `Elixir.PyroComponents.Components.Core.icon/1`\n  - `:class` `\"pyro_icon\"`\n\n- `Elixir.PyroComponents.Components.Core.input/1`\n  - `:clear_on_escape` `true`\n  - `:input_datetime_zoned_wrapper_class` `\"pyro_input__input_datetime_zoned_wrapper\"`\n  - `:class` `\"pyro_input\"`\n  - `:input_check_label_class` `\"pyro_input__input_check_label\"`\n  - `:get_tz_options` `Pyro.Component.Helpers.all_timezones/0`\n  - `:description_class` `\"pyro_input__description\"`\n  - `:input_class` `PyroComponents.Overrides.BEM.input_class/1`\n\n- `Elixir.PyroComponents.Components.Core.label/1`\n  - `:class` `\"pyro_label\"`\n\n- `Elixir.PyroComponents.Components.Core.list/1`\n  - `:class` `\"pyro_list\"`\n  - `:dt_class` `\"pyro_list__dt\"`\n  - `:dd_class` `\"pyro_list__dd\"`\n\n- `Elixir.PyroComponents.Components.Core.modal/1`\n  - `:hide_js` `PyroComponents.Overrides.BEM.modal_hide_js/2`\n  - `:show_js` `PyroComponents.Overrides.BEM.modal_show_js/2`\n  - `:class` `\"pyro_modal\"`\n\n- `Elixir.PyroComponents.Components.Core.nav_link/1`\n  - `:class` `PyroComponents.Overrides.BEM.nav_link_class/1`\n\n- `Elixir.PyroComponents.Components.Core.progress/1`\n  - `:sizes` `[\"xs\", \"sm\", \"base\", \"lg\", \"xl\"]`\n  - `:color` `\"slate\"`\n  - `:class` `PyroComponents.Overrides.BEM.progress_class/1`\n  - `:size` `\"base\"`\n  - `:colors` `[\"slate\", \"gray\", \"zinc\", \"neutral\", \"stone\", \"red\", \"orange\", \"amber\", \"yellow\", \"lime\", \"green\", \"emerald\", \"teal\", \"cyan\", \"sky\", \"blue\", \"indigo\", \"violet\", \"purple\", \"fuchsia\", \"pink\", \"rose\"]`\n\n- `Elixir.PyroComponents.Components.Core.simple_form/1`\n  - `:class` `\"pyro_simple_form\"`\n  - `:actions_class` `\"pyro_simple_form__actions\"`\n\n- `Elixir.PyroComponents.Components.Core.slide_over/1`\n  - `:close_icon_class` `\"pyro_slide_over__close_icon\"`\n  - `:hide_js` `PyroComponents.Overrides.BEM.slide_over_hide_js/5`\n  - `:header_class` `\"pyro_slide_over__header\"`\n  - `:close_icon_name` `\"hero-x-mark-solid\"`\n  - `:header_close_button_class` `\"pyro_slide_over__header_close_button\"`\n  - `:origin` `\"left\"`\n  - `:overlay_class` `\"pyro_slide_over__overlay\"`\n  - `:wrapper_class` `PyroComponents.Overrides.BEM.slide_over_wrapper_class/1`\n  - `:header_title_class` `\"pyro_slide_over__header_title\"`\n  - `:header_inner_class` `\"pyro_slide_over__header_inner\"`\n  - `:class` `PyroComponents.Overrides.BEM.slide_over_class/1`\n  - `:max_width` `\"base\"`\n  - `:max_widths` `[\"sm\", \"md\", \"lg\", \"xl\", \"2xl\", \"full\"]`\n  - `:origins` `[\"left\", \"right\", \"top\", \"bottom\"]`\n  - `:content_class` `\"pyro_slide_over__content\"`\n\n- `Elixir.PyroComponents.Components.Core.spinner/1`\n  - `:size` `\"base\"`\n  - `:class` `PyroComponents.Overrides.BEM.spinner_class/1`\n  - `:sizes` `[\"xs\", \"sm\", \"base\", \"lg\", \"xl\"]`\n\n- `Elixir.PyroComponents.Components.Core.table/1`\n  - `:thead_class` `\"pyro_table__thead\"`\n  - `:th_action_class` `\"pyro_table__th_action\"`\n  - `:action_wrapper_class` `\"pyro_table__action_wrapper\"`\n  - `:th_label_class` `\"pyro_table__th_label\"`\n  - `:td_class` `\"pyro_table__td\"`\n  - `:tbody_class` `\"pyro_table__tbody\"`\n  - `:action_td_class` `\"pyro_table__action_td\"`\n  - `:class` `\"pyro_table\"`\n  - `:tr_class` `\"pyro_table__tr\"`\n  - `:action_class` `\"pyro_table__action\"`\n\n- `Elixir.PyroComponents.Components.Core.tooltip/1`\n  - `:vertical_offset` `\"2.25rem\"`\n  - `:class` `\"pyro_tooltip\"`\n  - `:horizontal_offset` `\"0\"`\n  - `:icon_name` `\"hero-question-mark-circle-solid\"`\n  - `:tooltip_class` `\"pyro_tooltip__tooltip\"`\n  - `:tooltip_text_class` `\"pyro_tooltip__text\"`\n\n- Elixir.PyroComponents.Components.DataTable.cell/1 (private)\n  - `:class` `\"pyro_data_table__cell\"`\n\n- `Elixir.PyroComponents.Components.DataTable.data_table/1`\n  - `:row_class` `\"pyro_data_table__row\"`\n  - `:footer_class` `\"pyro_data_table__footer\"`\n  - `:footer_wrapper_class` `\"pyro_data_table__footer_wrapper\"`\n  - `:class` `\"pyro_data_table\"`\n  - `:header_class` `\"pyro_data_table__header\"`\n  - `:body_class` `\"pyro_data_table__body\"`\n\n- Elixir.PyroComponents.Components.DataTable.sort_icon/1 (private)\n  - `:sort_icon_name` `PyroComponents.Overrides.BEM.data_table_sort_icon_name/1`\n  - `:class` `\"pyro_data_table__sort_icon\"`\n  - `:index_class` `\"pyro_data_table__sort_icon_index\"`\n\n- Elixir.PyroComponents.Components.DataTable.th/1 (private)\n  - `:class` `PyroComponents.Overrides.BEM.data_table_th_class/1`\n  - `:btn_class` `PyroComponents.Overrides.BEM.data_table_sort_btn_class/1`\n\n- `Elixir.PyroComponents.Components.Pagination.pagination/1`\n  - `:last_icon` `\"hero-chevron-double-right-solid\"`\n  - `:next_icon_class` `\"pyro_pagination__next_icon\"`\n  - `:first_icon` `\"hero-chevron-double-left-solid\"`\n  - `:limit_form_input_option_class` `\"pyro_pagination__limit_form_input_option\"`\n  - `:reset_class` `\"pyro_pagination__reset\"`\n  - `:top_class` `\"pyro_pagination__top\"`\n  - `:limit_form_input_class` `\"pyro_pagination__limit_form_input\"`\n  - `:limit_form_label_class` `\"pyro_pagination__limit_form_label\"`\n  - `:previous_icon` `\"hero-chevron-left-solid\"`\n  - `:top_icon` `\"hero-chevron-double-up-solid\"`\n  - `:next_class` `\"pyro_pagination__next\"`\n  - `:first_icon_class` `\"pyro_pagination__first_icon\"`\n  - `:first_class` `\"pyro_pagination__first\"`\n  - `:previous_class` `\"pyro_pagination__previous\"`\n  - `:last_icon_class` `\"pyro_pagination__last_icon\"`\n  - `:previous_icon_class` `\"pyro_pagination__previous_icon\"`\n  - `:class` `\"pyro_pagination\"`\n  - `:last_class` `\"pyro_pagination__last\"`\n  - `:limit_form_class` `\"pyro_pagination__limit_form\"`\n  - `:next_icon` `\"hero-chevron-right-solid\"`\n  - `:top_icon_class` `\"pyro_pagination__top_icon\"`","ref":"PyroComponents.Overrides.BEM.html#module-overrides"},{"type":"function","title":"PyroComponents.Overrides.BEM.autocomplete_listbox_option_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#autocomplete_listbox_option_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.button_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#button_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.color_scheme_switcher_scheme/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#color_scheme_switcher_scheme/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.data_table_sort_btn_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#data_table_sort_btn_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.data_table_sort_icon_name/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#data_table_sort_icon_name/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.data_table_th_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#data_table_th_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.flash_hide_js/2","doc":"","ref":"PyroComponents.Overrides.BEM.html#flash_hide_js/2"},{"type":"function","title":"PyroComponents.Overrides.BEM.flash_icon_name/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#flash_icon_name/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.flash_show_js/2","doc":"","ref":"PyroComponents.Overrides.BEM.html#flash_show_js/2"},{"type":"function","title":"PyroComponents.Overrides.BEM.flash_title/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#flash_title/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.input_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#input_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.modal_hide_js/2","doc":"","ref":"PyroComponents.Overrides.BEM.html#modal_hide_js/2"},{"type":"function","title":"PyroComponents.Overrides.BEM.modal_show_js/2","doc":"","ref":"PyroComponents.Overrides.BEM.html#modal_show_js/2"},{"type":"function","title":"PyroComponents.Overrides.BEM.nav_link_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#nav_link_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.progress_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#progress_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.slide_over_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#slide_over_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.slide_over_hide_js/5","doc":"","ref":"PyroComponents.Overrides.BEM.html#slide_over_hide_js/5"},{"type":"function","title":"PyroComponents.Overrides.BEM.slide_over_width_class/1","doc":"","ref":"PyroComponents.Overrides.BEM.html#slide_over_width_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.slide_over_wrapper_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#slide_over_wrapper_class/1"},{"type":"function","title":"PyroComponents.Overrides.BEM.spinner_class/1","doc":"This override is passed component assigns and executed while being assigned at runtime.","ref":"PyroComponents.Overrides.BEM.html#spinner_class/1"},{"type":"module","title":"PyroComponents.Components.Autocomplete","doc":"A flexible autocomplete component for Phoenix forms.","ref":"PyroComponents.Components.Autocomplete.html"},{"type":"module","title":"Overridable Component Attributes - PyroComponents.Components.Autocomplete","doc":"You can customize the components in this module by [configuring overrides](`Pyro.Overrides`).\n\nThe components in this module support the following overridable attributes:\n\n- `render/1`\n  - `:throttle_time` `:integer` (required)\n  - `:option_label_key` `:atom` (required)\n  - `:option_value_key` `:atom` (required)\n  - `:prompt` `:string` (required)\n  - `:class` `:css_classes`\n  - `:input_class` `:css_classes`\n  - `:listbox_class` `:css_classes`\n  - `:listbox_option_class` `:css_classes`\n  - `:description_class` `:css_classes`","ref":"PyroComponents.Components.Autocomplete.html#module-overridable-component-attributes"},{"type":"function","title":"PyroComponents.Components.Autocomplete.render/1","doc":"A simple autocomplete component.","ref":"PyroComponents.Components.Autocomplete.html#render/1"},{"type":"function","title":"Examples - PyroComponents.Components.Autocomplete.render/1","doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.live_component\n        module={PyroComponents.Components.Autocomplete}\n        id=\"fiend_id_autocomplete\"\n        field={@form[:friend_id]}\n        label=\"Friend\"\n        search_fn={search_friends/1}\n        lookup_fn={lookup_friend/1} />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"PyroComponents.Components.Autocomplete.html#render/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Autocomplete.render/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `throttle_time` (`:integer`) - (overridable, required).\n* `option_label_key` (`:atom`) - (overridable, required).\n* `option_value_key` (`:atom`) - (overridable, required).\n* `prompt` (`:string`) - the prompt for search input (overridable, required).\n* `description` (`:string`) - Defaults to `nil`.\n* `errors` (`:list`) - Defaults to `[]`.\n* `label` (`:string`) - Defaults to `nil`.\n* `input_id` (`:any`) - Defaults to `nil`.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* `required` (`:boolean`) - Defaults to `false`.\n* `name` (`:any`)\n* `value` (`:any`)\n* `search_fn` (`:any`) (required) - the arity-1 function to get options from search term.\n* `lookup_fn` (`:any`) (required) - the arity-1 function to get lookup/convert value to option.\n* `no_results_message` (`:string`) - the message to display if there are no results for the search phrase. Defaults to `\"[no results]\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `autofocus` (`:boolean`) - enable autofocus hook to reliably focus input on mount. Defaults to `false`.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `input_class` (`:any`) - class of the input element (overridable, `:css_classes`).\n* `listbox_class` (`:any`) - class of the listbox element (overridable, `:css_classes`).\n* `listbox_option_class` (`:any`) - class of the listbox option element (overridable, `:css_classes`).\n* `description_class` (`:any`) - class of the field description (overridable, `:css_classes`).","ref":"PyroComponents.Components.Autocomplete.html#render/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Autocomplete.render/1","doc":"* `option_template`","ref":"PyroComponents.Components.Autocomplete.html#render/1-slots"},{"type":"module","title":"PyroComponents.Components.Core","doc":"A core set of functional `.heex` components for building web apps. It is similar to (and often API-compatible with) Phoenix's generated `core_components.ex`.\n\nCompared to Phoenix's generated components, Pyro's implementation adds:\n\n- Maintenance/bugfixes/new features, since it's a library\n- A powerful [override system](#module-overridable-component-attributes) for customization\n- A special `:css_classes` type that utilizes the configured CSS merge utility\n- The button component implements both button and anchor tags (button-styled links!)\n- Inputs\n  - `autofocus` prop to enable a hook for reliable focus on mount\n  - `hidden` input type with a slot for custom content\n- A rich flash experience\n  - Auto-remove after (configurable) timeout\n  - Progress bar for auto-removed flash messages\n  - Define which flashes are included in which trays (supports multiple trays)\n- Slightly cleaner, more semantic markup\n- Extra components\n\nThere are more complex components outside the `Core` module, be sure to check those out as well.","ref":"PyroComponents.Components.Core.html"},{"type":"module","title":"Overridable Component Attributes - PyroComponents.Components.Core","doc":"You can customize the components in this module by [configuring overrides](`Pyro.Overrides`).\n\nThe components in this module support the following overridable attributes:\n\n- `error/1`\n  - `:icon_name` `:string` (required)\n  - `:class` `:css_classes`\n  - `:icon_class` `:css_classes`\n\n- `code/1`\n  - `:copy` `:boolean` (required)\n  - `:copy_label` `:string` (required)\n  - `:copy_message` `:string`\n  - `:class` `:css_classes`\n  - `:copy_class` `:css_classes`\n\n- `input/1`\n  - `:clear_on_escape` `:boolean` (required)\n  - `:get_tz_options` `:any` (required)\n  - `:class` `:css_classes`\n  - `:input_class` `:css_classes`\n  - `:input_check_label_class` `:css_classes`\n  - `:input_datetime_zoned_wrapper_class` `:css_classes`\n  - `:description_class` `:css_classes`\n\n- `label/1`\n  - `:class` `:css_classes`\n\n- `list/1`\n  - `:class` `:css_classes`\n  - `:dd_class` `:css_classes`\n  - `:dt_class` `:css_classes`\n\n- `table/1`\n  - `:class` `:css_classes`\n  - `:action_class` `:css_classes`\n  - `:action_td_class` `:css_classes`\n  - `:action_wrapper_class` `:css_classes`\n  - `:tbody_class` `:css_classes`\n  - `:td_class` `:css_classes`\n  - `:th_action_class` `:css_classes`\n  - `:th_label_class` `:css_classes`\n  - `:thead_class` `:css_classes`\n  - `:tr_class` `:css_classes`\n\n- `progress/1`\n  - `:color` `:string` (required)\n  - `:size` `:string` (required)\n  - `:class` `:css_classes`\n\n- `header/1`\n  - `:class` `:css_classes`\n  - `:title_class` `:css_classes`\n  - `:subtitle_class` `:css_classes`\n  - `:actions_class` `:css_classes`\n\n- `a/1`\n  - `:replace` `:boolean` (required)\n  - `:class` `:css_classes`\n\n- `button/1`\n  - `:color` `:string` (required)\n  - `:size` `:string` (required)\n  - `:variant` `:string` (required)\n  - `:class` `:css_classes`\n  - `:icon_class` `:css_classes`\n  - `:ping_class` `:css_classes`\n  - `:ping_animation_class` `:css_classes`\n\n- `color_scheme_switcher/1`\n  - `:scheme` `:atom` (required)\n  - `:label_system` `:string`\n  - `:label_dark` `:string`\n  - `:label_light` `:string`\n  - `:icon_system` `:string`\n  - `:icon_dark` `:string`\n  - `:icon_light` `:string`\n  - `:class` `:css_classes`\n\n- `copy_to_clipboard/1`\n  - `:ttl` `:integer` (required)\n  - `:color` `:string` (required)\n  - `:shape` `:string` (required)\n  - `:size` `:string` (required)\n  - `:variant` `:string` (required)\n  - `:message` `:string` (required)\n  - `:class` `:css_classes`\n  - `:icon_class` `:css_classes`\n\n- `flash/1`\n  - `:autoshow` `:boolean` (required)\n  - `:close` `:boolean` (required)\n  - `:close_icon_name` `:string` (required)\n  - `:icon_name` `:string` (required)\n  - `:hide_js` `:any` (required)\n  - `:show_js` `:any` (required)\n  - `:title` `:string`\n  - `:ttl` `:integer` (required)\n  - `:kind` `:string` (required)\n  - `:style_for_kind` `:string`\n  - `:class` `:css_classes`\n  - `:control_class` `:css_classes`\n  - `:close_button_class` `:css_classes`\n  - `:close_icon_class` `:css_classes`\n  - `:message_class` `:css_classes`\n  - `:progress_class` `:css_classes`\n  - `:title_class` `:css_classes`\n  - `:title_icon_class` `:css_classes`\n\n- `flash_group/1`\n  - `:include_kinds` `:list` (required)\n  - `:class` `:css_classes`\n\n- `icon/1`\n  - `:class` `:css_classes`\n\n- `modal/1`\n  - `:show_js` `:any` (required)\n  - `:hide_js` `:any` (required)\n  - `:class` `:css_classes`\n\n- `nav_link/1`\n  - `:class` `:css_classes`\n\n- `simple_form/1`\n  - `:class` `:css_classes`\n  - `:actions_class` `:css_classes`\n\n- `slide_over/1`\n  - `:close_icon_name` `:string` (required)\n  - `:origin` `:string` (required)\n  - `:max_width` `:string` (required)\n  - `:hide_js` `:any` (required)\n  - `:class` `:css_classes`\n  - `:overlay_class` `:css_classes`\n  - `:wrapper_class` `:css_classes`\n  - `:header_class` `:css_classes`\n  - `:header_inner_class` `:css_classes`\n  - `:header_title_class` `:css_classes`\n  - `:header_close_button_class` `:css_classes`\n  - `:content_class` `:css_classes`\n  - `:close_icon_class` `:css_classes`\n\n- `spinner/1`\n  - `:size` `:string` (required)\n  - `:class` `:css_classes`\n\n- `tooltip/1`\n  - `:vertical_offset` `:string` (required)\n  - `:horizontal_offset` `:string` (required)\n  - `:icon_name` `:string` (required)\n  - `:class` `:css_classes`\n  - `:tooltip_class` `:css_classes`\n  - `:tooltip_text_class` `:css_classes`\n  - `:icon_class` `:css_classes`","ref":"PyroComponents.Components.Core.html#module-overridable-component-attributes"},{"type":"function","title":"PyroComponents.Components.Core.a/1","doc":"Renders a link. This basically wraps `Phoenix.Component.link/1` with some overridable attributes, in particular `class` for consistent, DRY link default styling.","ref":"PyroComponents.Components.Core.html#a/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.a/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `navigate` (`:string`) - Navigates from a LiveView to a new LiveView.\n  The browser page is kept, but a new LiveView process is mounted and its content on the page\n  is reloaded. It is only possible to navigate between LiveViews declared under the same router\n  `Phoenix.LiveView.Router.live_session/3`. Otherwise, a full browser redirect is used.\n\n  Defaults to `nil`.\n* `patch` (`:string`) - Patches the current LiveView.\n  The `handle_params` callback of the current LiveView will be invoked and the minimum content\n  will be sent over the wire, as any other LiveView diff.\n\n  Defaults to `nil`.\n* `href` (`:any`) - Uses traditional browser navigation to the new location.\n  This means the whole page is reloaded on the browser.\n\n  Defaults to `nil`.\n* `method` (`:string`) - The HTTP method to use with the link. This is intended for usage outside of LiveView\n  and therefore only works with the `href={...}` attribute. It has no effect on `patch`\n  and `navigate` instructions.\n  In case the method is not `get`, the link is generated inside the form which sets the proper\n  information. In order to submit the form, JavaScript must be enabled in the browser.\n\n  Defaults to `\"get\"`.\n* `csrf_token` (`:any`) - a boolean or custom token to use for links with an HTTP method other than `get`. Defaults to `true`.\n* `replace` (`:boolean`) - when using `:patch` or `:navigate`, should the browser's history be replaced with `pushState`? (overridable, required).\n* `class` (`:any`) - merge/override default classes of the `code` element (overridable, `:css_classes`).\n* Global attributes are accepted. additional HTML attributes added to the `a` tag.","ref":"PyroComponents.Components.Core.html#a/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.a/1","doc":"* `inner_block` (required) - the content rendered inside of the `a` tag.","ref":"PyroComponents.Components.Core.html#a/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.button/1","doc":"Renders a button.\n\nSupports:\n\n- Any button type\n- Any anchor type\n  - LivePatch\n  - LiveRedirect\n  - External href links","ref":"PyroComponents.Components.Core.html#button/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.button/1","doc":"<.button>Send!</.button>\n    <.button phx-click=\"go\" class=\"ml-2\">Send!</.button>\n    <.button navigate={~p\"/home\"}>Home</.button>","ref":"PyroComponents.Components.Core.html#button/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.button/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `confirm` (`:string`) - text to display in a confirm dialog before emitting click event. Defaults to `nil`.\n* `csrf_token` (`:string`) - Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* `href` (`:any`)\n* `icon_name` (`:string`) - the name of the icon to display (nil for none); see `icon/1` for details. Defaults to `nil`.\n* `loading` (`:boolean`) - display a loading spinner. Defaults to `false`.\n* `method` (`:string`) - Defaults to `\"get\"`.\n* `navigate` (`:string`)\n* `patch` (`:string`)\n* `ping` (`:boolean`) - show a ping indicator. Defaults to `false`.\n* `replace` (`:boolean`) - Defaults to `false`.\n* `type` (`:string`) - type of the button. Defaults to `\"button\"`.\n* `color` (`:string`) - the color of the button (overridable, required).\n* `size` (`:string`) - the size of the button (overridable, required).\n* `variant` (`:string`) - style of button (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `icon_class` (`:any`) - (overridable, `:css_classes`).\n* `ping_class` (`:any`) - (overridable, `:css_classes`).\n* `ping_animation_class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted. Supports all globals plus: `[\"download\", \"hreflang\", \"referrerpolicy\", \"rel\", \"target\", \"form\", \"name\", \"value\"]`.","ref":"PyroComponents.Components.Core.html#button/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.button/1","doc":"* `inner_block` (required) - the content of the button.","ref":"PyroComponents.Components.Core.html#button/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.code/1","doc":"Renders a code block.","ref":"PyroComponents.Components.Core.html#code/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.code/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `source` (`:string`) (required) - the code snippet.\n* `id` (`:string`) (required)\n* `copy` (`:boolean`) - (overridable, required).\n* `copy_label` (`:string`) - (overridable, required).\n* `copy_message` (`:string`) - (overridable).\n* `language` (`:string`) - language of the code snippet. Defaults to `\"elixir\"`.\n* `class` (`:any`) - merge/override default classes of the `code` element (overridable, `:css_classes`).\n* `copy_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#code/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.color_scheme_switcher/1","doc":"A color scheme switch component.\n\n- Toggle through light, dark, and system color schemes\n- Optionally show labels for each scheme\n- Optionally override the default labels for each scheme with `label_system`, `label_dark`, and `label_light`\n- Optionally override the default icons for each scheme with `icon_system`, `icon_dark`, and `icon_light`\n\n> ##","ref":"PyroComponents.Components.Core.html#color_scheme_switcher/1"},{"type":"function","title":"Note: {: .info} - PyroComponents.Components.Core.color_scheme_switcher/1","doc":">\n> This requires several things to work:\n>   - `darkMode: 'class'` in your Tailwind config\n>   - `color_scheme_switcher_js/1` added to the page's ` ` before `app.js`\n>   - Pyro's `PyroColorSchemeHook` hook added to your hooks in `app.js`","ref":"PyroComponents.Components.Core.html#color_scheme_switcher/1-note-info"},{"type":"function","title":"Examples - PyroComponents.Components.Core.color_scheme_switcher/1","doc":"<.color_scheme_switcher />\n\n    <.color_scheme_switcher scheme=\"light\" />\n    <.color_scheme_switcher scheme=\"dark\" />\n    <.color_scheme_switcher scheme=\"system\" />\n\n    <.color_scheme_switcher show_labels />\n\n    <.color_scheme_switcher label_system=\"System\" label_dark=\"Dunkel\" label_light=\"Hell\" />\n    <.color_scheme_switcher icon_system=\"hero-computer-desktop-solid\" icon_dark=\"hero-moon-solid\" icon_light=\"hero-sun-solid\" />","ref":"PyroComponents.Components.Core.html#color_scheme_switcher/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.color_scheme_switcher/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `scheme` (`:atom`) - the scheme used to initialize the color scheme switcher (overridable, required).\n* `label_system` (`:string`) - the label for the system scheme (overridable).\n* `label_dark` (`:string`) - the label for the dark scheme (overridable).\n* `label_light` (`:string`) - the label for the light scheme (overridable).\n* `icon_system` (`:string`) - the icon for the system scheme (overridable).\n* `icon_dark` (`:string`) - the icon for the dark scheme (overridable).\n* `icon_light` (`:string`) - the icon for the light scheme (overridable).\n* `show_labels` (`:boolean`) - show or hide labels. Defaults to `false`.\n* `class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#color_scheme_switcher/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.color_scheme_switcher_js/1","doc":"Javascript to manage switching color schemes with `color_scheme_switcher/1`.\n\n> ##","ref":"PyroComponents.Components.Core.html#color_scheme_switcher_js/1"},{"type":"function","title":"Note: {: .info} - PyroComponents.Components.Core.color_scheme_switcher_js/1","doc":">\n> This needs to be added in the page's head before `app.js` to prevent FOUC:\n\n```heex\n \n  <.color_scheme_switcher_js />\n   \n \n```","ref":"PyroComponents.Components.Core.html#color_scheme_switcher_js/1-note-info"},{"type":"function","title":"PyroComponents.Components.Core.copy_to_clipboard/1","doc":"","ref":"PyroComponents.Components.Core.html#copy_to_clipboard/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.copy_to_clipboard/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `id` (`:string`) (required)\n* `value` (`:string`) (required) - text to copy.\n* `label` (`:string`) - button label, defaults to value. Defaults to `nil`.\n* `disabled` (`:boolean`) - Defaults to `false`.\n* `icon_name` (`:string`) - the name of the icon to display (nil for none); see `icon/1` for details. Defaults to `nil`.\n* `ttl` (`:integer`) - how long to show the flash message after copying (overridable, required).\n* `color` (`:string`) - the color of the button (overridable, required).\n* `shape` (`:string`) - shape of the button (overridable, required).\n* `size` (`:string`) - the size of the button (overridable, required).\n* `variant` (`:string`) - style of button (overridable, required).\n* `message` (`:string`) - message to display after copying (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `icon_class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted.","ref":"PyroComponents.Components.Core.html#copy_to_clipboard/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.error/1","doc":"Generates a generic error message.","ref":"PyroComponents.Components.Core.html#error/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.error/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `icon_name` (`:string`) - the name of the icon; see `icon/1` for details (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `icon_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#error/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.error/1","doc":"* `inner_block` (required)","ref":"PyroComponents.Components.Core.html#error/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.flash/1","doc":"Renders flash notices.","ref":"PyroComponents.Components.Core.html#flash/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.flash/1","doc":"<.flash kind={:info} flash={@flash} />\n    <.flash kind={:info} phx-mounted={show(\"#flash\")}>Welcome Back!</.flash>","ref":"PyroComponents.Components.Core.html#flash/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.flash/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `autoshow` (`:boolean`) - whether to auto show the flash on mount (overridable, required).\n* `close` (`:boolean`) - whether the flash can be closed (overridable, required).\n* `close_icon_name` (`:string`) - (overridable, required).\n* `icon_name` (`:string`) - (overridable, required).\n* `hide_js` (`:any`) - (overridable, required).\n* `show_js` (`:any`) - (overridable, required).\n* `title` (`:string`) - (overridable).\n* `ttl` (`:integer`) - (overridable, required).\n* `kind` (`:string`) - used for styling and flash lookup (overridable, required).\n* `style_for_kind` (`:string`) - used for styling a flash with a different kind (overridable).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `control_class` (`:any`) - (overridable, `:css_classes`).\n* `close_button_class` (`:any`) - (overridable, `:css_classes`).\n* `close_icon_class` (`:any`) - (overridable, `:css_classes`).\n* `message_class` (`:any`) - (overridable, `:css_classes`).\n* `progress_class` (`:any`) - (overridable, `:css_classes`).\n* `title_class` (`:any`) - (overridable, `:css_classes`).\n* `title_icon_class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"PyroComponents.Components.Core.html#flash/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.flash/1","doc":"* `inner_block` - the optional inner block to render the flash message.","ref":"PyroComponents.Components.Core.html#flash/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.flash_group/1","doc":"Shows the flash group with titles and content.","ref":"PyroComponents.Components.Core.html#flash_group/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.flash_group/1","doc":"<.flash_group flash={@flash} />","ref":"PyroComponents.Components.Core.html#flash_group/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.flash_group/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `flash` (`:map`) (required) - the map of flash messages to display.\n* `include_kinds` (`:list`) - the kinds of flashes to display (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash tray.","ref":"PyroComponents.Components.Core.html#flash_group/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.header/1","doc":"Renders a header with title and optional subtitle/actions.","ref":"PyroComponents.Components.Core.html#header/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.header/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `title_class` (`:any`) - (overridable, `:css_classes`).\n* `subtitle_class` (`:any`) - (overridable, `:css_classes`).\n* `actions_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#header/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.header/1","doc":"* `inner_block` (required)\n* `subtitle`\n* `actions`","ref":"PyroComponents.Components.Core.html#header/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.icon/1","doc":"Renders an icon.\n\n> ##","ref":"PyroComponents.Components.Core.html#icon/1"},{"type":"function","title":"Tip {: .info} - PyroComponents.Components.Core.icon/1","doc":">\n> See the [Heroicons website](https://heroicons.com/) to preview/search the available icons.\n\nAdditionally, there are long-term plans to add more icon libraries.","ref":"PyroComponents.Components.Core.html#icon/1-tip-info"},{"type":"function","title":"Examples - PyroComponents.Components.Core.icon/1","doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 animate-spin\" />","ref":"PyroComponents.Components.Core.html#icon/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.icon/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `name` (`:string`) (required) - the icon name.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"PyroComponents.Components.Core.html#icon/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.input/1","doc":"Renders an input with label and error messages.\n\nA `Phoenix.HTML.FormField` may be passed as argument,\nwhich is used to retrieve the input name, id, and values.\nOtherwise all attributes may be passed explicitly.","ref":"PyroComponents.Components.Core.html#input/1"},{"type":"function","title":"Types - PyroComponents.Components.Core.input/1","doc":"This function accepts all HTML input types, considering that:\n\n  * You may also set `type=\"select\"` to render a ` ` tag\n\n  * `type=\"checkbox\"` is used exclusively to render boolean values\n\n  * For live file uploads, see `Phoenix.Component.live_file_input/1`\n\nSee https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input\nfor more information.","ref":"PyroComponents.Components.Core.html#input/1-types"},{"type":"function","title":"Examples - PyroComponents.Components.Core.input/1","doc":"<.input field={@form[:email]} type=\"email\" />\n    <.input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"PyroComponents.Components.Core.html#input/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.input/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `autofocus` (`:boolean`) - enable autofocus hook to reliably focus input on mount. Defaults to `false`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `description` (`:string`) - Defaults to `nil`.\n* `errors` (`:list`) - Defaults to `[]`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `id` (`:any`) - Defaults to `nil`.\n* `label` (`:string`) - Defaults to `nil`.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* `name` (`:any`)\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `value` (`:any`)\n* `clear_on_escape` (`:boolean`) - clear input value on pressing Escape (overridable, required).\n* `tz` (`:string`) - timezone. Defaults to `\"Etc/UTC\"`.\n* `get_tz_options` (`:any`) - a 0 arity function that returns a list of valid timezones (overridable, required).\n* `tz_options` (`:list`) - Defaults to `nil`.\n* `class` (`:any`) - class of the field container element (overridable, `:css_classes`).\n* `input_class` (`:any`) - class of the input element (overridable, `:css_classes`).\n* `input_check_label_class` (`:any`) - class of the label element for a check input (overridable, `:css_classes`).\n* `input_datetime_zoned_wrapper_class` (`:any`) - class of the input wrapper element for a datetime zoned input (overridable, `:css_classes`).\n* `description_class` (`:any`) - class of the field description (overridable, `:css_classes`).\n* Global attributes are accepted. Supports all globals plus: `[\"accept\", \"autocomplete\", \"capture\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"PyroComponents.Components.Core.html#input/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.input/1","doc":"* `inner_block`","ref":"PyroComponents.Components.Core.html#input/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.label/1","doc":"Renders a label.","ref":"PyroComponents.Components.Core.html#label/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.label/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `for` (`:string`) - Defaults to `nil`.\n* `class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#label/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.label/1","doc":"* `inner_block` (required)","ref":"PyroComponents.Components.Core.html#label/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.list/1","doc":"Renders a description list.","ref":"PyroComponents.Components.Core.html#list/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.list/1","doc":"<.list>\n      <:item title=\"Title\"><%= @post.title %></:item>\n      <:item title=\"Views\"><%= @post.views %></:item>\n    </.list>","ref":"PyroComponents.Components.Core.html#list/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.list/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `dd_class` (`:any`) - (overridable, `:css_classes`).\n* `dt_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#list/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.list/1","doc":"* `item` (required) - Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"PyroComponents.Components.Core.html#list/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.modal/1","doc":"Renders a modal.","ref":"PyroComponents.Components.Core.html#modal/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.modal/1","doc":"<.modal id=\"confirm-modal\">\n      Are you sure?\n      <:confirm>OK</:confirm>\n      <:cancel>Cancel</:cancel>\n    </.modal>\n\nJS commands may be passed to the `:on_cancel` and `on_confirm` attributes\nfor the caller to react to each button press, for example:\n\n    <.modal id=\"confirm\" on_confirm={JS.push(\"delete\")} on_cancel={JS.navigate(~p\"/posts\")}>\n      Are you sure you?\n      <:confirm>OK</:confirm>\n      <:cancel>Cancel</:cancel>\n    </.modal>","ref":"PyroComponents.Components.Core.html#modal/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.modal/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `id` (`:string`) (required)\n* `show` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.\n* `on_confirm` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.\n* `show_js` (`:any`) - (overridable, required).\n* `hide_js` (`:any`) - (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#modal/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.modal/1","doc":"* `inner_block` (required)\n* `title`\n* `subtitle`\n* `confirm`\n* `cancel`","ref":"PyroComponents.Components.Core.html#modal/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.nav_link/1","doc":"Renders a navigation link, taking into account whether the URI is the current page.","ref":"PyroComponents.Components.Core.html#nav_link/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.nav_link/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `label` (`:string`) (required) - the label of of the link.\n* `uri` (`:string`) (required) - the URI of the link.\n* `current_uri` (`:string`) (required) - the current URI of the page.\n* `class` (`:any`) - the class of the navigation link (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#nav_link/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.progress/1","doc":"A progress element. Styling the progress element is tricky, so this wraps it with some nice conveniences.","ref":"PyroComponents.Components.Core.html#progress/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.progress/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `max` (`:integer`) - Defaults to `100`.\n* `value` (`:integer`) - Defaults to `0`.\n* `color` (`:string`) - the color of the progress bar (overridable, required).\n* `size` (`:string`) - the size of the progress bar (overridable, required).\n* `class` (`:any`) - the class of the progress bar (overridable, `:css_classes`).\n* Global attributes are accepted.","ref":"PyroComponents.Components.Core.html#progress/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.simple_form/1","doc":"Renders a simple form.","ref":"PyroComponents.Components.Core.html#simple_form/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.simple_form/1","doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.input field={@form[:email]} label=\"Email\"/>\n      <.input field={@form[:username]} label=\"Username\" />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"PyroComponents.Components.Core.html#simple_form/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.simple_form/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `for` (`:any`) (required) - the datastructure for the form.\n* `as` (`:any`) - the server side parameter to collect all input under. Defaults to `nil`.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `actions_class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted. the arbitrary HTML attributes to apply to the form tag. Supports all globals plus: `[\"autocomplete\", \"name\", \"rel\", \"action\", \"enctype\", \"method\", \"novalidate\", \"target\", \"multipart\"]`.","ref":"PyroComponents.Components.Core.html#simple_form/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.simple_form/1","doc":"* `inner_block` (required)\n* `actions` - the slot for form actions, such as a submit button.","ref":"PyroComponents.Components.Core.html#simple_form/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.slide_over/1","doc":"A slide-over component.","ref":"PyroComponents.Components.Core.html#slide_over/1"},{"type":"function","title":"Example - PyroComponents.Components.Core.slide_over/1","doc":"<%= if @slide_over do %>\n      <.slide_over origin={@slide_over} max_width=\"sm\" title=\"Slide Over\">\n         \n          This is a slide over.\n         \n      </.slide_over>\n    <% end %>","ref":"PyroComponents.Components.Core.html#slide_over/1-example"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.slide_over/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `close_icon_name` (`:string`) - (overridable, required).\n* `title` (`:string`) - the title of the slide-over.\n* `id` (`:string`) - Defaults to `\"slide-over\"`.\n* `origin` (`:string`) - (overridable, required).\n* `max_width` (`:string`) - (overridable, required).\n* `hide_js` (`:any`) - (overridable, required).\n* `close_even_name` (`:string`) - the name of the event to send when the slide-over is closed. Defaults to `\"close_slide_over\"`.\n* `close_slide_over_target` (`:string`) - the specific live component to target for the close event, e.g. close_slide_over_target={@myself}. Defaults to `nil`.\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `overlay_class` (`:any`) - (overridable, `:css_classes`).\n* `wrapper_class` (`:any`) - (overridable, `:css_classes`).\n* `header_class` (`:any`) - (overridable, `:css_classes`).\n* `header_inner_class` (`:any`) - (overridable, `:css_classes`).\n* `header_title_class` (`:any`) - (overridable, `:css_classes`).\n* `header_close_button_class` (`:any`) - (overridable, `:css_classes`).\n* `content_class` (`:any`) - (overridable, `:css_classes`).\n* `close_icon_class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted.","ref":"PyroComponents.Components.Core.html#slide_over/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.slide_over/1","doc":"* `inner_block` (required)","ref":"PyroComponents.Components.Core.html#slide_over/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.spinner/1","doc":"A simple spinner component.","ref":"PyroComponents.Components.Core.html#spinner/1"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.spinner/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `show` (`:boolean`) - show or hide spinner. Defaults to `true`.\n* `size` (`:string`) - the size of the spinner (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* Global attributes are accepted.","ref":"PyroComponents.Components.Core.html#spinner/1-attributes"},{"type":"function","title":"PyroComponents.Components.Core.table/1","doc":"Renders a simple table with generic styling.","ref":"PyroComponents.Components.Core.html#table/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.table/1","doc":"<.table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\"><%= user.id %></:col>\n      <:col :let={user} label=\"username\"><%= user.username %></:col>\n    </.table>","ref":"PyroComponents.Components.Core.html#table/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.table/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `id` (`:string`)\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.\n* `rows` (`:list`) (required)\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `action_class` (`:any`) - (overridable, `:css_classes`).\n* `action_td_class` (`:any`) - (overridable, `:css_classes`).\n* `action_wrapper_class` (`:any`) - (overridable, `:css_classes`).\n* `tbody_class` (`:any`) - (overridable, `:css_classes`).\n* `td_class` (`:any`) - (overridable, `:css_classes`).\n* `th_action_class` (`:any`) - (overridable, `:css_classes`).\n* `th_label_class` (`:any`) - (overridable, `:css_classes`).\n* `thead_class` (`:any`) - (overridable, `:css_classes`).\n* `tr_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#table/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.table/1","doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.","ref":"PyroComponents.Components.Core.html#table/1-slots"},{"type":"function","title":"PyroComponents.Components.Core.tooltip/1","doc":"A tooltip component.\n\n- JS hook that \"nudges\" tooltip into view\n- Simple props for tooltip text and custom icon\n- Optional slots for icon and/or tooltip content","ref":"PyroComponents.Components.Core.html#tooltip/1"},{"type":"function","title":"Examples - PyroComponents.Components.Core.tooltip/1","doc":"<.tooltip id=\"tooltip-1\" tooltip=\"A default tooltip!\" />\n    <.tooltip id=\"tooltip-2\"\n              icon_name=\"hero-light-bulb-solid\"\n              tooltip=\"Custom icon.\" />\n    <.tooltip id=\"tooltip-3\">\n      <:icon>?</:icon>\n       \n        Custom tooltip slot and custom icon slot.\n       \n    </.tooltip>","ref":"PyroComponents.Components.Core.html#tooltip/1-examples"},{"type":"function","title":"Attributes - PyroComponents.Components.Core.tooltip/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `id` (`:string`) (required)\n* `tooltip` (`:string`) - Defaults to `nil`.\n* `vertical_offset` (`:string`) - (overridable, required).\n* `horizontal_offset` (`:string`) - (overridable, required).\n* `icon_name` (`:string`) - the name of the icon; see `icon/1` for details (overridable, required).\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `tooltip_class` (`:any`) - (overridable, `:css_classes`).\n* `tooltip_text_class` (`:any`) - (overridable, `:css_classes`).\n* `icon_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.Core.html#tooltip/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.Core.tooltip/1","doc":"* `icon`\n* `inner_block`","ref":"PyroComponents.Components.Core.html#tooltip/1-slots"},{"type":"module","title":"PyroComponents.Components.DataTable","doc":"Tooling and components for rendering data tables.","ref":"PyroComponents.Components.DataTable.html"},{"type":"module","title":"Overridable Component Attributes - PyroComponents.Components.DataTable","doc":"You can customize the components in this module by [configuring overrides](`Pyro.Overrides`).\n\nThe components in this module support the following overridable attributes:\n\n- `data_table/1`\n  - `:class` `:css_classes`\n  - `:header_class` `:css_classes`\n  - `:body_class` `:css_classes`\n  - `:row_class` `:css_classes`\n  - `:footer_class` `:css_classes`\n  - `:footer_wrapper_class` `:css_classes`\n\n- `th/1`\n  - `:class` `:css_classes`\n  - `:btn_class` `:css_classes`\n\n- `cell/1`\n  - `:class` `:css_classes`\n\n- `sort_icon/1`\n  - `:sort_icon_name` `:string`\n  - `:class` `:css_classes`\n  - `:index_class` `:css_classes`","ref":"PyroComponents.Components.DataTable.html#module-overridable-component-attributes"},{"type":"function","title":"PyroComponents.Components.DataTable.data_table/1","doc":"A complex data table component, featuring streams, multi-column sorting and pagination.\n\nIt is a functional component, so all emitted events are to be handled by the parent LiveView.","ref":"PyroComponents.Components.DataTable.html#data_table/1"},{"type":"function","title":"Attributes - PyroComponents.Components.DataTable.data_table/1","doc":"* `overrides` (`:list`) - Manually set the overrides for this component (instead of config/default). Defaults to `nil`.\n* `id` (`:string`) (required)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.\n* `rows` (`:list`) (required)\n* `page_limit_options` (`:list`) - Defaults to `[10, 25, 50, 100, 250, 500, 1000]`.\n* `page` (`:map`) - Defaults to `nil`.\n* `sort` (`:list`) (required)\n* `class` (`:any`) - (overridable, `:css_classes`).\n* `header_class` (`:any`) - (overridable, `:css_classes`).\n* `body_class` (`:any`) - (overridable, `:css_classes`).\n* `row_class` (`:any`) - (overridable, `:css_classes`).\n* `footer_class` (`:any`) - (overridable, `:css_classes`).\n* `footer_wrapper_class` (`:any`) - (overridable, `:css_classes`).","ref":"PyroComponents.Components.DataTable.html#data_table/1-attributes"},{"type":"function","title":"Slots - PyroComponents.Components.DataTable.data_table/1","doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n  * `class` (`:string`)\n  * `cell_class` (`:string`)\n  * `sort_key` (`:atom`)\n* `header_action` - the slot for showing user actions in the last table column header.\n* `action` - the slot for showing user actions in the last table column.","ref":"PyroComponents.Components.DataTable.html#data_table/1-slots"},{"type":"function","title":"PyroComponents.Components.DataTable.encode_display/1","doc":"Stringifies the columns to display for storage in a url param.","ref":"PyroComponents.Components.DataTable.html#encode_display/1"},{"type":"function","title":"PyroComponents.Components.DataTable.encode_sort/1","doc":"Stringifies the column sorting for storage in a url param.","ref":"PyroComponents.Components.DataTable.html#encode_sort/1"},{"type":"function","title":"PyroComponents.Components.DataTable.toggle_sort/4","doc":"Toggles the column sorting.","ref":"PyroComponents.Components.DataTable.html#toggle_sort/4"},{"type":"extras","title":"About","doc":"# About\n\nPyro is a suite of libraries for building UI in Phoenix.\n\n- [Pyro](https://hexdocs.pm/pyro)\n\n  Component tooling for Phoenix.\n\n  - Customizable \"overrides\" system for granularly customizable themes\n  - Extended component attributes, e.g. CSS merging\n\n- [PyroComponents](https://hexdocs.pm/pyro_components)\n\n  Ready-made Phoenix components, built with pyro.\n\n  - Heex component library\n  - Overrides presets to get started quickly while allowing deep customization\n\n- [AshPyro](https://hexdocs.pm/ash_pyro)\n\n  Declarative UI for Ash Framework.\n\n  - Ash extensions providing a declarative UI DSL\n\n- [AshPyroComponents](https://hexdocs.pm/ash_pyro_components)\n\n  Components that automatically render PyroComponents declaratively via AshPyro.\n\nTo install PyroComponents and use them in your Phoenix app, follow the [Get Started](get-started.html) guide. For the other features, please see the \"Get Started\" guide for the appropriate library instead.","ref":"about.html"},{"type":"extras","title":"What \"problem\" is it solving? - About","doc":"The default model of Phoenix is to generate, then customize. While this does provide great isolation, I have found it pretty tedious to repeatedly make very similar copy & paste boilerplate changes to the generated code every time I create a new Phoenix app. Additionally, some things (like timezone localization) are quite complicated and it would be nice for them to be handled by a library that is updated with future improvements. Copy & pasting boilerplate will lead to maintenance burdens down the road.\n\nThe tricky part is handling all the bespoke features in each app while sharing as much as possible. The goal is to provide a wide array of tooling, helpers and components with sane defaults, while allowing very granular overrides and optional libraries. By separating each level of features, you can choose which parts of Pyro to leverage, and which to implement yourself.","ref":"about.html#what-problem-is-it-solving"},{"type":"extras","title":"General Principles - About","doc":"PyroComponents is under-developed. Not all components adhere to every principle, but eventually these principles should prevail:\n\n- Maximal flexibility\n  - Application defaults through presets & custom overrides\n  - Components allow overriding defaults through props\n- Clean, standards-compliant HTML markup\n  - Favor semantic HTML elements\n  - Avoid excessive `div` tags\n  - Adhere to [accessibility guidelines](https://www.w3.org/WAI/ARIA/apg/)\n- Progressive enhancement\n  - No external JS dependencies\n  - No needless JS\n  - Sensibly enhance UX with JS\n- Responsive\n- Internationalization support via `gettext`","ref":"about.html#general-principles"},{"type":"extras","title":"Customizing Component Style","doc":"# Customizing Component Style\n\nFinding a balance of reusability and customizability can be quite a challenge for styling components. Many patterns have emerged, each with different compromises. For example:\n\n- [BEM](https://getbem.com/) maximizes composability and simplicity at the cost of verbosity and separating the style from the markup\n- [Tailwind](https://tailwindcss.com/) maximizes simplicity and standardization at the cost of HTML density and composability\n- Root class with selectors minimizes markup at the cost of complexity and composability\n- [CSS in JS](https://cssinjs.org/) - Just... No.\n\nThis guide steps through some of the things to consider when it comes to choosing a strategy for _your_ use case with Pyro.","ref":"customizing-component-style.html"},{"type":"extras","title":"Goals - Customizing Component Style","doc":"Pyro aims to make it easy to do the following with the default skin:\n\n- Cover 90% of what you want out of the box\n- Granularly tweak that custom 10%\n- Override anything ad-hoc when using a component\n\nPyro also aims to:\n\n- Reduce the need for hacks like `!important`\n- Make those customizations maintainable\n- **Not** produce HTML with a dozen classes in _every_ `td`\n\nWith the above in mind, let's look at some strategies we could apply. Please keep in mind that, while we have chosen a solution that combines Tailwind + component classes + custom variants, Pyro provides the tools for you to choose any strategy you like.","ref":"customizing-component-style.html#goals"},{"type":"extras","title":"CSS Strategies - Customizing Component Style","doc":"#","ref":"customizing-component-style.html#css-strategies"},{"type":"extras","title":"BEM - Customizing Component Style","doc":"[BEM](https://getbem.com/) has a simple naming pattern for single classes that you apply to every element needing style. This incredibly simple system eliminates class hierarchy/inheritance concerns, and also leaves room for utility/override classes to be used so long as they are defined after the component classes.\n\nPyroComponents provides a BEM overrides file to help you get started using a BEM skin strategy. It provides no style by default, and adds BEM classes to each element of the components. This allows you to create a fully-custom skin with very little friction. Installation and configuration instructions can be found in the module docs for `PyroComponents.Overrides.BEM`.\n\nPros:\n\n- Simple name\n- Clear targeting\n- No specificity conflicts\n- No precedence conflicts\n\nCons:\n\n- Class names can become quite long\n- HTML can be heavy, especially with variants\n- Unless you add conditional variants, dynamic style can be tricky\n- No default styles, more work to get started","ref":"customizing-component-style.html#bem"},{"type":"extras","title":"Tailwind Strategies - Customizing Component Style","doc":"#","ref":"customizing-component-style.html#tailwind-strategies"},{"type":"extras","title":"Utilities Only - Customizing Component Style","doc":"Tailwind encourages a [utility-first](https://tailwindcss.com/docs/utility-first) workflow, and gives a lot of tips on how to [apply that to components](https://tailwindcss.com/docs/reusing-styles). That approach does have its challenges from a library perspective.\n\nUtility classes have equal precedence, so overriding the skin ad-hoc can be tricky. Workarounds include:\n\n- Using the `!` modifier, e.g. `!bg-red0500`\n- Truncating/removing classes with `Pyro.Component.CSS.classes/1`\n- Auto-merging with [Tails](https://hexdocs.pm/tails/Tails.html)\n\nPros:\n\n- No names or hierarchy\n- Follows Tailwind's official recommendations\n- Style in markup\n\nCons:\n\n- Utility precedence conflicts\n- HTML heavier than `node_modules`\n- **All** variants will be included in CSS\n- Style in markup 🤣\n\n#","ref":"customizing-component-style.html#utilities-only"},{"type":"extras","title":"BEM + Tailwind - Customizing Component Style","doc":"Tailwind can also be used with BEM classes. Pyro provides default styles for this strategy, as well as an overrides file that adds all the needed component classes.\n\nDetails can be found at `PyroComponents.Overrides.BEM`.\n\nPros:\n\n- Simple/clear naming/targeting\n- No conflicts with utility classes\n\nCons:\n\n- Class names can become quite long\n- Unless you add conditional variants, dynamic style can be tricky\n- No default styles, more work to get started","ref":"customizing-component-style.html#bem-tailwind"},{"type":"extras","title":"Get Started","doc":"# Get Started\n\nThis guide steps through the installation process for PyroComponents.","ref":"get-started.html"},{"type":"extras","title":"Installation - Get Started","doc":"The installation process is pretty straightforward, and many of the steps can be customized depending on how you want to use PyroComponents.\n\n#","ref":"get-started.html#installation"},{"type":"extras","title":"Steps - Get Started","doc":"These steps assume you are adding PyroComponents to an existing Phoenix LiveView app, as generated from the most recent version of `phx.new`.\n\n1. Add `:pyro` to your dependencies:\n\n   ```elixir\n   def deps do\n     [\n    {:pyro, \"~> 0.2.0\"},\n    {:pyro_components, \"~> 0.1.0\"},\n\n    # Heroicon support in components\n    {:heroicons,\n      github: \"tailwindlabs/heroicons\",\n      tag: \"v2.1.1\",\n      app: false,\n      compile: false,\n      sparse: \"optimized\"},\n\n    #","ref":"get-started.html#steps"},{"type":"extras","title":"OPTIONAL DEPS BELOW ### - Get Started","doc":"# Date/Time/Zone components & tooling\n    {:tz, \"~> 0.26\"},\n    {:tz_extra, \"~> 0.26\"},\n    #   or\n    {:tzdata, \"~> 1.1\"},\n\n    # Code highlighting components:\n    {:makeup, \"~> 1.1\"},\n    {:makeup_eex, \"~> 0.1\"},\n    {:makeup_elixir, \"~> 0.16\"},\n    {:makeup_html, \"~> 0.1\"},\n    {:makeup_js, \"~> 0.1\"},\n    {:makeup_json, \"~> 0.1\"},\n     ]\n   end\n   ```\n\n2. Add `:pyro` to your `.formatter.exs`:\n\n   ```elixir\n   [\n     import_deps: [:ecto, :ecto_sql, :phoenix, :pyro],\n     subdirectories: [\"priv/*/migrations\"],\n     plugins: [Phoenix.LiveView.HTMLFormatter],\n     inputs: [\"*.{heex,ex,exs}\", \"{config,lib,test}/**/*.{heex,ex,exs}\", \"priv/*/seeds.exs\"]\n   ]\n   ```\n\n3. Add the following to your `config.exs`:\n\n   ```elixir\n   config :pyro, :overrides, [PyroComponents.Overrides.BEM]\n   config :pyro, gettext: MyApp.Gettext # optional\n   ```\n\n4. Configure your `tailwind.config.js` according to this example:\n\n   ```js\n   const path = require('path')\n\n   module.exports = {\n     // Dark mode support\n     darkMode: 'class',\n     content: [\n       // The usual defaults\n       './js/**/*.js',\n       '../lib/my_app_web.ex',\n       '../lib/my_app_web/**/*.*ex',\n\n       // Add the directory you will be keeping resources since\n       // we need to include any classes referenced in the UI DSL\n       '../lib/my_app/**/*.ex',\n\n       // Add your chosen Pyro overrides file(s)\n       '../deps/pyro_components/lib/pyro_components/overrides/bem.ex',\n     ],\n     plugins: [\n       // Pyro expects the forms plugin\n       require('@tailwindcss/forms'),\n       // Add Pyro's Tailwind plugin\n       require(path.join(\n         __dirname,\n         '../deps/pyro_components/assets/js/tailwind-plugin.js',\n       ))({\n         heroIconsPath: path.join(__dirname, '../deps/heroicons/optimized'),\n         addBase: true,\n       }),\n\n       // Pyro replaces Phoenix's generated plugin stuff, you can delete it!\n     ],\n   }\n   ```\n\n   > ##","ref":"get-started.html#optional-deps-below"},{"type":"extras","title":"Note: {: .warning} - Get Started","doc":">\n   > Using `path.join(.__dirname, '...')` is important; Tailwind CLI will get confused without it!\n\n5. Add the following lines to `assets/js/app.js`:\n\n   ```js\n   import { hooks, getTimezone } from 'pyro'\n\n   let liveSocket = new LiveSocket('/live', Socket, {\n     params: { _csrf_token: csrfToken, timezone: getTimezone() },\n     hooks: { ...hooks },\n   })\n   ```\n\n6. Edit your `my_app_web.ex` file, replacing:\n\n   - `Phoenix.Component` with `Pyro.Component`\n   - `Phoenix.LiveComponent` with `Pyro.LiveComponent`\n   - `Phoenix.LiveView` with `Pyro.LiveView`\n\n   **Note:** _Only_ replace those top-level modules, _do not_ replace submodules, e.g. `Phoenix.LiveView.Router`.\n\n7. (Optional) Import the Pyro components into your `my_app_web.ex` helpers to make the available in your views/components:\n\n   ```elixir\n   defp html_helpers do\n     quote do\n       # Import all Pyro components\n       use PyroComponents\n       # Don't import CoreComponents since PyroComponents replaces it and will conflict\n       # import MyAppWeb.CoreComponents\n       # ...\n   ```\n\n8. (Optional) Add the color scheme JS to your `root.html.heex` template (prevents [FOUC](https://en.wikipedia.org/wiki/Flash_of_unstyled_content)):\n\n   ```heex\n    \n     <.color_scheme_switcher_js />\n      \n    \n   ```\n\n   At this point, you probably want to delete the old `core_components.ex` file, since Pyro will replace that functionality (mostly API-compatible).\n\n9. (Optional) configure some runtime options in `runtime.exs`:\n\n   ```elixir\n   config :pyro, default_timezone: \"America/Chicago\"\n   ```","ref":"get-started.html#note-warning"}],"content_type":"text/markdown"}